classdef IceLoadCroasdale
    %Calculates ice forces based on Croasdale method. A 3D breaking term is
    %used, while the ride-up/down term is 2D as this is considered a good
    %representation of the reality. For a downward sloping cone, the
    %equation derived by Timco & Cornett is used. See section 5.2.2 in
    %thesis.
    
    %% PROPERTIES
    properties
       HorizontalForce
       VerticalForce
       Platform
       EnvParameters
       IceParameters 
    end %properties
    properties(GetAccess ='private', SetAccess = 'private')
        C1
        C2
        C3
        C4
        e1
        e2
        e3
        e4
        L
    end %properties
    
    %% METHODS
    methods
        %Class constructor
        function obj = IceLoadCroasdale(Platform,EnvParameters,IceParameters)
            obj.Platform = Platform;
            obj.EnvParameters = EnvParameters;
            obj.IceParameters = IceParameters;        
        end %function
    end %methods
    
    methods(Access=private)
        
        function obj = characteristicLength(obj)
            obj.L = ((obj.IceParameters.E*obj.IceParameters.h.^3)...
                    ./(12*obj.EnvParameters.rho_w*obj.EnvParameters.g...
                    *(1-obj.IceParameters.nu^2))).^0.25; 
        end %function 
        
        function obj = constants(obj)
            
            if obj.Platform.alpha > 0 %Upward sloping cone
            obj.e1 = obj.IceParameters.mu * cos(obj.Platform...
                .alpha) + sin(obj.Platform.alpha);
            
            obj.e2 = -obj.IceParameters.mu * sin(obj.Platform...
                .alpha) + cos(obj.Platform.alpha);
            
            obj.C1 = 0.68*((obj.e1)/(obj.e2));
            
            obj.C2 = obj.e1*((obj.e1)/(obj.e2) ...
                     +cot(obj.Platform.alpha));
                         
            elseif obj.Platform.alpha < 0 %Downward sloping cone
            obj.e3 = obj.IceParameters.mu * cos(obj.Platform...
                .alpha) - sin(obj.Platform.alpha);
            
            obj.e4 = obj.IceParameters.mu * sin(obj.Platform...
                .alpha) + cos(obj.Platform.alpha);
            
            obj.C3 = 0.68*((obj.e3)/(obj.e4));
            
            obj.C4 = obj.e3*((obj.e3)/(obj.e4) ...
                     -cot(obj.Platform.alpha));
                 
                 
            elseif obj.Platform.alpha == 0
                disp('Slope angle of structure is not valid (=0)')
                return
            end
            
        end %function
        
    end %methods
    
    methods
        %Calling function "horizontalForce"
        obj = horizontalForce(obj)
        
        %Calling function "verticalForce"
        obj = verticalForce(obj)
    end %methods
      
    
end