classdef IceLoadRalston
   %Calculates ice forces from Ralston's equation. Theory explained in
   %section 5.2.1 of the thesis.
   
   %% PROPERTIES
   properties
       HorizontalForce
       VerticalForce
       Platform
       EnvParameters
       IceParameters 
   end %properties
   properties(GetAccess ='private', SetAccess = 'private')
       Rho
       A1
       A2
       K
       E
       H
       F
       G
       A3
       A4
       B1
       B2
   end %properties
   
   %% METHODS
   methods 
       %Class constructor
       function obj=IceLoadRalston(Platform,EnvParameters,IceParameters)
           obj.Platform = Platform;
           obj.EnvParameters = EnvParameters;
           obj.IceParameters = IceParameters;    
       end    
   end %methods
   
   methods(Access = private)
 
       function obj = newtonRaphsonIteration(obj)
           %Perform iteration to determine correct ratio between radius of
           %deforming area A and radius of cone at waterline using
           %Newton-Raphson iteration.

            for i = 1:20
                if i == 1
                    rho = 2; %initial start value (must not be =1)
                end %if
                Func  = rho-log(rho)+0.0830*(2*rho+1)...
                    *(rho-1)^2*((obj.EnvParameters.rho_w...
                    *obj.EnvParameters.g...
                    *obj.Platform.D^2)...
                    ./(obj.IceParameters.sigma_f...
                    .*obj.IceParameters.h))-1.369;
                dFunc = 1 - 1/rho + 0.498*(rho^2-rho)...
                    *((obj.EnvParameters.rho_w*obj.EnvParameters.g...
                    *obj.Platform.D^2)...
                    ./(obj.IceParameters.sigma_f...
                    .*obj.IceParameters.h));
                rho = rho - ((Func)/(dFunc));
                %TODO: Add check of error (While loop?)   
            end %for
            obj.Rho = rho;
       end %function
   
       function obj = a1(obj)
           %Determine coefficient A1
           obj.A1 = (1+2.711*obj.Rho*log(obj.Rho))/(3*(obj.Rho-1));
       end %function
       
       function obj = a2(obj)
           %Determine coefficient A2
           obj.A2 = 0.075*(obj.Rho^2 + obj.Rho - 2);
       end %function
       
       function obj = KE(obj)
           %Use Matlabs built in function to determine the complete
           %elliptic intergrals of first and second kind.
           [k,e] = ellipke((sin(abs(obj.Platform.alpha)))^2);
           obj.K = k;
           obj.E = e;
       end %function
       
       function obj = h(obj)
           %Intermediate coefficient h
           obj.H = cos(abs(obj.Platform.alpha))...
                 - ((obj.IceParameters.mu)...
                 /(sin(abs(obj.Platform.alpha))))...
                 *(obj.E-(cos(abs(obj.Platform.alpha)))^2*obj.K);
       end %function
       
       function obj = f(obj)
           %Intermediate coefficient f
           obj.F = sin(abs(obj.Platform.alpha)) ...
               + obj.IceParameters.mu...
               *cos(abs(obj.Platform.alpha))*obj.K;
       end %function
       
       function obj = g(obj)
           %Intermediate coefficient g
           obj.G = (0.5+(abs(obj.Platform.alpha))...
               ./(sin(2.*abs(obj.Platform.alpha))))...
               ./(0.25*pi.*sin(abs(obj.Platform.alpha))...
               +(obj.IceParameters.mu...
               .*abs(obj.Platform.alpha))...
               ./(tan(abs(obj.Platform.alpha)))); 
       end %function
       
       function obj = a3(obj)
           %Determine coefficient A3
           obj.A3 = (0.9)/(4*cos(abs(obj.Platform.alpha)))...
               *((1 + (obj.IceParameters.mu*obj.E)...
               /(tan(abs(obj.Platform.alpha))))...
               - obj.IceParameters.mu...
               *sin(abs(obj.Platform.alpha))*obj.F*obj.G);   
       end %function
       
       function obj = a4(obj)
           %Determine coefficient A4
           obj.A4 = (tan(abs(obj.Platform.alpha)))...
               /(1-obj.IceParameters.mu*obj.G);
       
       end %function
     
       function obj = b1(obj)
           %Determine coefficient B1
           obj.B1 = (obj.H)/(0.25*pi*sin(abs(obj.Platform.alpha))...
               + (obj.IceParameters.mu...
               *abs(obj.Platform.alpha)...
               /(tan(abs(obj.Platform.alpha)))));
       end %function
       
       function obj = b2(obj)
           %Determine coefficient B2
           obj.B2 = (0.9/4)*(0.5*pi.*cos(abs(obj.Platform.alpha))...
               - obj.IceParameters.mu...
               *abs(obj.Platform.alpha)...
               - ((obj.F*obj.H)/(0.25*pi*sin(abs(obj.Platform.alpha))...
               +(obj.IceParameters.mu...
               *abs(obj.Platform.alpha))...
               /(tan(abs(obj.Platform.alpha)))))); 
       end %function
   end %methods
   
   methods
       %Calculate horizontal force
       obj = horizontalForce(obj)              
   end %methods
   
   methods
       %Calculate vertical force
       obj = verticalForce(obj)
   end %methods

    
    
    
end %class