
classdef IceLoadRidgeRalston
%IceLoadRidgeRalston: Calculate loads from multi-year ridge based on 
%   theory by Ralston. Explained in section 5.4.1 in thesis.
    
    %% PROPERTIES
    properties
        VerticalForceInitial
        VerticalForceCrack
        HorizontalForceInitial
        HorizontalForceCrack
        Platform
        EnvParameters
        IceParameters
    end %properties
    
    properties(GetAccess ='private', SetAccess = 'private')
        I
        Y_b
        Y_t
        l
    end %properties
    
    %% METHODS
    methods
        %Class constructor
        function obj = IceLoadRidgeRalston(Platform,EnvParameters,IceParameters)
            obj.Platform = Platform;
            obj.EnvParameters = EnvParameters;
            obj.IceParameters = IceParameters;        
        end %function
        
        function obj = CalculateVerticalInitForce(obj)
            obj = obj.CalculateY();
            obj = obj.CalculateI();
            obj = obj.CharacteristicLength();
            
            obj.VerticalForceInitial = (4*obj.I*obj.IceParameters.sigma_r)...
                /(obj.Y_b*obj.l);
        end
        
        function obj = CalculateVerticalForceCrack(obj)
            obj = obj.CalculateY();
            obj = obj.CalculateI();
            obj = obj.CharacteristicLength();
            
            obj.VerticalForceCrack = (6.2*obj.I*obj.IceParameters.sigma_r)...
                /(obj.Y_b*obj.l);
        end
        
        function obj = CalculateHorizontalInitForce(obj)
            obj = obj.CalculateVerticalInitForce();
            
            obj.HorizontalForceInitial = obj.VerticalForceInitial...
                *(obj.IceParameters.mu*cos(obj.Platform.alpha)-sin(obj.Platform.alpha))/...
                        (obj.IceParameters.mu*sin(obj.Platform.alpha)+cos(obj.Platform.alpha));
        end
        
        function obj = CalculateHorizontalForceCrack(obj)
            obj = obj.CalculateVerticalForceCrack();
            
            obj.HorizontalForceCrack = obj.VerticalForceCrack...
                *(obj.IceParameters.mu*cos(obj.Platform.alpha)-sin(obj.Platform.alpha))/...
                        (obj.IceParameters.mu*sin(obj.Platform.alpha)+cos(obj.Platform.alpha));
        end
    end %methods
    
    methods(Access = private)
        function obj = CalculateI(obj)
            obj.I = (obj.IceParameters.B_t*obj.IceParameters.h_r^3)/12;
        end
        
        function obj = CalculateY(obj)
            obj.Y_b = 0.5*obj.IceParameters.h_r;
            obj.Y_t = 0.5*obj.IceParameters.h_r;
        end
        
        function obj = CharacteristicLength(obj)
            obj = obj.CalculateI();
            
            obj.l = ((4*obj.IceParameters.E*obj.I)/(obj.EnvParameters.rho_w...
                *obj.IceParameters.B_t*obj.EnvParameters.g))^(0.25);
            
            
        end
    end %methods
    
    
    
end %classdef