classdef IceLoadRidgeWang
    %Calculates forces from a multi-year ridge on a downward sloping cone.
    %Calculations are based on Wang's theory, explained in section 5.4.2
    %and appendix B in thesis.
    
    %% PROPERTIES 
    properties
        HorizontalForce
        VerticalForce
        Platform
        EnvParameters
        IceParameters
    end %properties
    
    properties(GetAccess ='private', SetAccess = 'private')
        a   % distance
        b   % distance
        d   % distance
        A   % distance a / Top width of ridge
        B   % distance b / Top width of ridge
        D   % distance d / Top width of ridge
        R   % bottom width of ridge / top width of ridge
        S   % ice sheet strength / ridge strength
        T   % ice sheet thickness / ridge thickness
        Q   % = R for downward breaking of ridge, = 1for upward
        g   % unit weight of water - unit weight of ice (downward)  
        G   % weight / bending 
        F_a 
        F_b
        F_r
        F_d
        C_0
        C_1
        C_2
        C_3
        C_4
        ro
        x
    end %properties
    
    %% METHODS
    methods
        %Class constructor
        function obj = IceLoadRidgeWang(Platform,EnvParameters,IceParameters)
            obj.Platform = Platform;
            obj.EnvParameters = EnvParameters;
            obj.IceParameters = IceParameters;        
        end %function
    end %methods
    
    methods(Access=private)
      
        function obj = CalculateR(obj)
            obj.R = obj.IceParameters.B_b ./ obj.IceParameters.B_t;      
        end %function
        
        function obj = CalculateS(obj)
            obj.S = obj.IceParameters.sigma_f / obj.IceParameters.sigma_r;      
        end %function       

        function obj = CalculateT(obj)
            if length(obj.IceParameters.h) == 1
                obj.T = obj.IceParameters.h ./ obj.IceParameters.h_r;
            else
                obj.T = 2 ./ obj.IceParameters.h_r;
            end
            % 2 instead of level ice thickness
        end %function
        
        function obj = CalculateQ(obj)
            if obj.Platform.alpha < 0
                obj.Q = obj.R;      
            else
                obj.Q = 1;
            end
        end %function
        
        function obj = Calculateg(obj)
            if obj.Platform.alpha < 0
                obj.g = obj.EnvParameters.g...
                *(obj.EnvParameters.rho_w - obj.IceParameters.rho_i);   
            else
                obj.g = obj.EnvParameters.g*obj.IceParameters.rho_i;
            end
        end %function
        
        function obj = CalculateG(obj)
            obj = obj.Calculateg();
            
            obj.G = (obj.g*obj.IceParameters.B_t.^2)./(obj.IceParameters.sigma_r...
                    .*obj.IceParameters.h_r);      
        end %function
        
        function obj = CalculateF_a(obj)
            obj = obj.CalculateR();
            obj = obj.CalculateG();
            obj = obj.CalculateQ();
            obj = obj.CalculateS();
            
            obj.F_a = ((obj.G.*(7+7.*obj.R+obj.R.^2+obj.R.^3))/(8))...
                      + ((1+4.*obj.R+obj.R.^2)./(1+obj.R+obj.Q));
        end %function
        
        function obj = CalculateF(obj)
            obj = obj.CalculateR();
            obj = obj.CalculateG();
            obj = obj.CalculateQ();
            obj = obj.CalculateF_a();
            obj = obj.CalculateT();
            
            obj.F_r = (3*(1+4.*obj.R+obj.R.^2).*(1+obj.R))./((1+2.*obj.R).*(2+obj.R));
            obj.F_b = obj.F_a + obj.S*obj.T.^2 - 1.5*obj.G.*(1+obj.R);
        end %function
    end %methods
    
    methods
        function obj = CalculateForces(obj)
            obj = obj.CalculateS();
            obj = obj.CalculateT();
            obj = obj.CalculateF();
            
            
            
            obj.x = 4*obj.S.*obj.T.^2.*sqrt((obj.F_a)./(obj.F_r));
            
            if obj.F_b <= obj.x
                obj.A = sqrt((obj.F_r)/(obj.F_a));
                obj.B = 0;
                obj.D = 0;
                
                obj.VerticalForce = ((obj.IceParameters.sigma_r...
                    *obj.IceParameters.h_r^2 * (obj.A*obj.F_a-obj.B...
                    *obj.F_b))/(3));
                
                obj.HorizontalForce = obj.VerticalForce...
                    *tan(abs(obj.Platform.alpha)+atan(obj.IceParameters.mu));
                
            elseif obj.F_b > obj.x
                obj.C_0 = 4*obj.F_a.*(2*obj.S.*obj.T.^2).^2 - (obj.F_r.*obj.F_b.^2);
                
                obj.C_1 = 8*obj.S.*obj.T.^2.*(obj.F_a.*(obj.F_a+2*obj.S.*obj.T.^2)-obj.F_b.^2);
                
                obj.C_2 = (obj.F_a+2.*obj.S.*obj.T.^2).*(obj.F_a.*(obj.F_a+2 ...
                    .*obj.S.*obj.T.^2)-obj.F_b.^2)...
                    +16.*(obj.F_a.*obj.S.*obj.T.^2.*obj.G.*obj.T)...
                    +((obj.F_r.*obj.F_b.^2.*obj.G.*obj.T)./(2.*obj.S.*obj.T.^2));
                
                obj.C_3 = 4.*obj.F_a.*obj.G.*obj.T.*(obj.F_a + 2.*obj.S.*obj.T.^2);
                
                obj.C_4 = obj.F_a.*(2.*obj.G.*obj.T).^2;
                
                p = [obj.C_4 obj.C_3 obj.C_2 obj.C_1 obj.C_0];
                
                obj.ro = roots(p);
                
                for i = length(obj.ro)
                    if p(i) > 0
                        obj.D = obj.ro(i);
                    end %if
                end %for
                
                obj.B = sqrt(1./((1./obj.D^2)-((obj.G.*obj.T)...
                    ./(2.*obj.S.*obj.T.^2))));
                
                obj.F_d = 2*obj.S*obj.T^2 + 2*obj.G*obj.T*obj.D + ((4*obj.S*obj.T^2)/(obj.D));
                
                obj.A = ((obj.B*(obj.F_a+obj.F_d))/(obj.F_b));
                
                obj.VerticalForce = ((obj.IceParameters.sigma_r...
                    *obj.IceParameters.h_r^2 * (obj.A*obj.F_a-obj.B...
                    *obj.F_b))/(3));
                
                obj.HorizontalForce = obj.VerticalForce...
                    *((obj.IceParameters.mu*cos(obj.Platform.alpha)-sin(obj.Platform.alpha))/...
                        (obj.IceParameters.mu*sin(obj.Platform.alpha)+cos(obj.Platform.alpha)));
                
            end %if
            
                obj.a = obj.A*obj.IceParameters.B_t;
                
                obj.b = obj.B*obj.IceParameters.B_t;
                
                obj.d = obj.D*obj.IceParameters.B_t;
           
        end %function
    end %method
        
    
    
    
end %classdef