classdef Input
    %INPUT Class that holds all the user defined values
    %   Values are assigned directly in this class. All values that user is
    %   able to change are listed in this file. Parameters are divided into
    %   groups according to what they give information about.
    %   Names and symbols must not be changed, only numbers!
    %   Input values follow table 5.1 in section 5.8 of the thesis.
    
    properties % General parameters
        % Acceleration of gravity, [m/s^2]:
        g = 9.81;
        % Density of sea water, [kg/m^3]:
        rho_w = 1025;
        % Density of air, [kg/m^3]:
        rho_a = 1.225;
        % Maximum wind speed, [m/s]:
        V_w = 39;
        % Water depth at location of platform, [m]:
        d = 500;
    end 
    
    properties % Platform dimensions
        % Waterline diameter, [m]:
        D = 100;
        % Rubble ridedown/up diameter, [m]:
        D_r = 70;
        % Slope angle, [deg]:
        alpha = -45;
        % Depth/height of sloping part, [m]:
        t = 15;
    end
    
    properties % Ice parameters
        % Friction coefficient platform/ice, [-]:
        mu = 0.1;
        % Density of ice, [kg/m^3]:
        rho_i = 917;
        % Flexural strength of ice, [Pa]:
        sigma_f = 0.5*10^6;
        % Elastic modulus of ice, [Pa]:
        E = 5*10^9;
        % Poisson ration of ice, [-]:
        nu = 0.3;
        % Level ice thickness, [m]:
        h = 2;
        %h
        
        % Keel depth, first-year ridge, [m]:
        h_k = 25;
        %h_k
        % Sail height, first-year ridge, [m]:
        h_s = 5;
        %h_s
        % Sail width, first-year ridge, [m]:
        B_s = 6.25;
        % Angle of internal friction, first-year ridge, [deg]:
        omega = 45;
        % Void ratio of rubble in first-year ridge, [-]:
        n = 0.3;
        % Thickness of ridge, [m]:
        h_r = 20;
        %h_r
        % Top width of ridge, [m]:
        B_t = 110;
        %B_t
        % Bottom width of ridge, [m]:
        B_b = 40;
        %B_b
        % Flexural strength of ridge ice, [Pa]:
        sigma_r = 0.5*10^6;
        
        % Thickness of managed floes, [m]:
        h_f = 2;
        %h_f
        % Porosity of ice, [-]:
        e = 0.3;
        % Ice rubble firction coefficient, [-]:
        phi = 0;
        % Ice rubble cohesion , [Pa]:
        c = 1500;
        % Bearing capacity, [-]:
        K = 6;
        % Vertical to lateral rubble pressure ratio, [-]:
        K_0 = 1;
        % Ice pressure, [Pa]:
        p = 15000;
        % Angle of stationary ice rubble block infront of platform, [deg]:
        theta = 45;
        
        % Length and width of ice floe, [m]:
        L = 10000;
        % Average pack-ice force, [N/m]:
        w = 100000;
        % Wind drag coefficient of ice floe, [-]:
        C_w = 2*10^-3;
        
        % Ice drift speed, [m/s]:
        V = 0.08;
    end
    
    properties % Mooring System
        % Length of mooring line, [m]
        l = 3000;
        % Weight of mooring line in water, [N/m]:
        W = 4500;
        % Minimum breaking strength of chain, [N]:
        MBS = 31*10^6;
        % Horizontal pre-tension (set as 30% of MBS), [N]:
        TH = 9.3*10^6;
        % Number of mooring lines, [-]:
        i = 24;
        % Diameter of turret, [m]:
        D_turret = 20;  
    end
    
    methods
        % Class constructor
         function obj = Input()
         end
        
        % Second constructor for range calculations
%         function obj = Input(h,h_r,B_t,B_b,h_f,h_s,h_k)
%             obj.h = h;
%             obj.h_r = h_r;
%             obj.B_t = B_t;
%             obj.B_b = B_b;
%             obj.h_f = h_f;
%             obj.h_k = h_k;
%             obj.h_s = h_s;
%        end
    end
    
end

