classdef RestoringCoefficients
    %Calculates restoring coefficients of mooring system, based on
    %equations for catenary mooring lines in section 6.1 of thesis. Can only be
    %used for mooring systems with four connection points.
    
    properties  
       C11
       C22
       C66
       k
       X
       MooringParameters
       EnvParameters
    end %properties
    
    methods
       %Class constructor
       function obj=RestoringCoefficients(MooringParameters,EnvParameters)
           obj.MooringParameters = MooringParameters;  
           obj.EnvParameters = EnvParameters;
       end %function
    end %methods
    
    methods(Access = private)
        
        %Function to calculate equilibrium position, i.e. horizontal 
        %distance from anchor to structure
        function obj = EquilibriumPosition(obj)
        obj.X = obj.MooringParameters.l - obj.EnvParameters.d*(1+2*((obj.MooringParameters.TH)/(obj.MooringParameters.W*obj.EnvParameters.d)))^0.5...
                + ((obj.MooringParameters.TH)/(obj.MooringParameters.W))*acosh(1+((obj.MooringParameters.W*obj.EnvParameters.d)/(obj.MooringParameters.TH)));
        end %function
        
        %Function to calculate stiffness of indivual line
        function obj = LineStiffness(obj)
            A = ((-2)/(sqrt(1+2*((obj.MooringParameters.TH)/(obj.MooringParameters.W*obj.EnvParameters.d)))));
            B = acosh(1+((obj.MooringParameters.W*obj.EnvParameters.d)/(obj.MooringParameters.TH)));
            obj.k = obj.MooringParameters.W*(A+B)^(-1);
        end %function
            
    end %methods
    
    methods
        %Calculate restoring coefficient C11
        function obj = RestoringCoeffC11(obj)
           obj = obj.EquilibriumPosition();
           obj = obj.LineStiffness();
           
           A = 0;
           psi = 0;
           
           for j = 1:obj.MooringParameters.i
               if j == 1
                   % First anchor line has an angle of 15 deg.
                   psi = (7.5*pi)/180;
               else
                   % Following anchor lines have an angle of 30 deg 
                   % between them.
                   psi = psi + ((15*pi)/180);
               end
               A = A + (cos(psi))^2;
           end

           obj.C11 = obj.k*A;      
        end %function
        
        %Calculate restoring coefficient C22
        function obj = RestoringCoeffC22(obj)
           obj = obj.EquilibriumPosition();
           obj = obj.LineStiffness();
           
           A = 0;
           psi = 0;
           
           for j = 1:obj.MooringParameters.i
               if j == 1
                   % First anchor line has an angle of 15 deg.
                   psi = (15*pi)/180;
               else
                   % Following anchor lines have an angle of 30 deg 
                   % between them.
                   psi = psi + ((30*pi)/180);
               end
               A = A + (sin(psi))^2;
           end
           
           obj.C22 = obj.k*A;      
        end %function
        
        
        %Calculate restoring coefficient C66
        function obj = RestoringCoeffC66(obj)
           obj = obj.EquilibriumPosition();
           obj = obj.LineStiffness();
           
          
           A = 0;
           
           
           for j = 1:obj.MooringParameters.i
               if j == 1
                   % First anchor line has an angle of 15 deg.
                   psi = (15*pi)/180;
               else
                   % Following anchor lines have an angle of 30 deg 
                   % between them.
                   psi = psi + ((30*pi)/180);
               end
               
               if j == 1 || j == 2 || j == 3  
                   x = cos((45*pi)/180)*obj.MooringParameters.D_turret;
                   y = sin((45*pi)/180)*obj.MooringParameters.D_turret;
               elseif j == 4 || j == 5 || j == 6 
                   x = -cos((45*pi)/180)*obj.MooringParameters.D_turret;
                   y = sin((45*pi)/180)*obj.MooringParameters.D_turret;
               elseif j == 7 || j == 8 || j == 9 
                   x = -cos((45*pi)/180)*obj.MooringParameters.D_turret;
                   y = -sin((45*pi)/180)*obj.MooringParameters.D_turret;
               else
                   x = cos((45*pi)/180)*obj.MooringParameters.D_turret;
                   y = -sin((45*pi)/180)*obj.MooringParameters.D_turret;
               end
               A = A + (x*sin(psi)-y*cos(psi))^2;
           end        
           obj.C66 = obj.k*A;      
        end %function

    end
   
end