% Script for plotting ice loads for certain varying parameters. 
% In order to use this script the Input.m file in the @Input folder must 
% be changed to accept vectors of the following parameters, h, h_r, B_t, 
% B_b, h_f, h_k and h_s. This is done by commenting out the values given in
% the Input.m file, and replacing with the parameter name only: 
% ("h" instead of "h=2").

clear all
clc
close all


%Remove value given to the following parameters in the Input-file:
%Range of level ice thickness
h = 0:0.024:6;
%Range of ridge thickness
h_r = 10:0.1:35;
%Range of top breadth of ridge
B_t = 55:0.55:192.5;
%Range of bottom breadth of ridge
B_b = 20:0.2:70;
%Range of floe thickness in managed ice
h_f = 0:0.016:4;
%Range of FY ridge keel depth
h_k = 5:0.10:30;
%Range of FY ridge sail height
h_s = 3:0.012:6;


%% Perform calculations of level ice loads over a range of thicknesses

for i = 1:251
    clear InputRange Platform EnvParameters IceParameters IceLoadRalston IceLoadCroasdale
    clear MooringParameters RestoringCoefficients
    
    InputRange = Input(h(i),h_r(i),B_t(i),B_b(i),h_f(i),h_s(i),h_k(i));
    Platform = Platform(InputRange);
    EnvParameters = EnvParameters(InputRange);
    IceParameters = IceParameters(InputRange);
    MooringParameters = MooringParameters(InputRange);
    
    IceLoadRalston = IceLoadRalston(Platform,EnvParameters,IceParameters);
    IceLoadRalston = IceLoadRalston.horizontalForce();
    
    IceLoadCroasdale = IceLoadCroasdale(Platform,EnvParameters,IceParameters);
    IceLoadCroasdale = IceLoadCroasdale.horizontalForce();
    
    RestoringCoefficients = RestoringCoefficients(MooringParameters,EnvParameters);
    RestoringCoefficients = RestoringCoefficients.RestoringCoeffC11();
   
    FHR(i) = IceLoadRalston.HorizontalForce;
    FHC(i) = IceLoadCroasdale.HorizontalForce;
    R11(i) = RestoringCoefficients.C11*25;
end


%% Perform calculations for ridges

for i = 1:251
    clear Input Platform EnvParameters IceParameters IceLoadRalston IceLoadCroasdale
    clear MooringParameters RestoringCoefficients IceLoadRidgeWang IceLoadRidgeRalston
    clear IceLoadRidgeDolgopolov IceLoadRidgeMellor
    
    InputRange = Input(h(83),h_r(i),B_t(i),B_b(i),h_f(i),h_s(i),h_k(i));
    Platform = Platform(InputRange);
    EnvParameters = EnvParameters(InputRange);
    IceParameters = IceParameters(InputRange);
    MooringParameters = MooringParameters(InputRange);
    
    %Contribution from consolidated layer, assumed to be 4m
    IceLoadCroasdaleConsolidated = IceLoadCroasdale(Platform,EnvParameters,IceParameters);
    IceLoadCroasdaleConsolidated = IceLoadCroasdaleConsolidated.horizontalForce(); 
    IceLoadRalstonConsolidated = IceLoadRalston(Platform,EnvParameters,IceParameters);
    IceLoadRalstonConsolidated = IceLoadRalstonConsolidated.horizontalForce(); 
    
    if IceLoadRalstonConsolidated.HorizontalForce > IceLoadCroasdaleConsolidated.HorizontalForce
        ConsolidatedLayer = IceLoadRalstonConsolidated.HorizontalForce;
    else
        ConsolidatedLayer = IceLoadCroasdaleConsolidated.HorizontalForce;
    end
    
    IceLoadRidgeDolgopolov = IceLoadRidgeDolgopolov(Platform,EnvParameters,IceParameters);
    IceLoadRidgeDolgopolov = IceLoadRidgeDolgopolov.CalculateHorizontalForce();
    DolgopolovTotal = IceLoadRidgeDolgopolov.HorizontalForce + ConsolidatedLayer;
    
    IceLoadRidgeMellor = IceLoadRidgeMellor(Platform,EnvParameters,IceParameters);
    IceLoadRidgeMellor = IceLoadRidgeMellor.CalculateForces();
    MellorTotal = IceLoadRidgeMellor.HorizontalForce + ConsolidatedLayer;
    
    IceLoadRidgeWang = IceLoadRidgeWang(Platform,EnvParameters,IceParameters);
    IceLoadRidgeWang = IceLoadRidgeWang.CalculateForces();
    
    IceLoadRidgeRalston = IceLoadRidgeRalston(Platform,EnvParameters,IceParameters);

    IceLoadRidgeRalston = IceLoadRidgeRalston.CalculateVerticalInitForce();
    IceLoadRidgeRalston = IceLoadRidgeRalston.CalculateVerticalForceCrack();
    IceLoadRidgeRalston = IceLoadRidgeRalston.CalculateHorizontalInitForce();
    IceLoadRidgeRalston = IceLoadRidgeRalston.CalculateHorizontalForceCrack();
    
    FHD(i)  = DolgopolovTotal;
    FHM(i)  = MellorTotal;
    FHRW(i) = IceLoadRidgeWang.HorizontalForce;
    FHIn(i) = IceLoadRidgeRalston.HorizontalForceInitial;
    FHCr(i) = IceLoadRidgeRalston.HorizontalForceCrack;
    
end


%% Ice loads in managed ice

for i = 1:251
    clear Input Platform EnvParameters IceParameters  
    clear MooringParameters RestoringCoefficients IceLoadManagedIce
    
    InputRange = Input(h(i),h_r(i),B_t(i),B_b(i),h_f(i),h_s(i),h_k(i));
    Platform = Platform(InputRange);
    EnvParameters = EnvParameters(InputRange);
    IceParameters = IceParameters(InputRange);
    MooringParameters = MooringParameters(InputRange);
    
    IceLoadManagedIce = IceLoadManagedIce(Platform,EnvParameters,IceParameters);
    IceLoadManagedIce = IceLoadManagedIce.Scenario1();
    IceLoadManagedIce = IceLoadManagedIce.Scenario2();
    IceLoadManagedIce = IceLoadManagedIce.Scenario3();

    
    FHS1(i) = IceLoadManagedIce.HForceScenario1;
    FHS2(i) = IceLoadManagedIce.HForceScenario2;
    FHS3(i) = IceLoadManagedIce.HForceScenario3;
    
end



% figure(1);
% plot(h,FHR,'b')
% grid on 
% xlabel('Level Ice Thickness, [m]')
% ylabel('Horizontal Ice Force, [N]')
% hold on
% plot(h,FHC,'k')
% plot(h,R11,'r')
% legend('Ralston','Croasdale','Maximum allowable force','Location','NorthWest')

figure(2)
plot(h_k,FHD,'k')
grid on 
xlabel('Keel depth, [m]')
ylabel('Horizontal Ice Force, [N]')
hold on
plot(h_k,FHM,'b')
plot(h_k,R11,'r')
legend('Dolgopolov + consolidated layer','Mellor + consolidated layer','Maximum allowable force','Location','NorthWest')

% figure(3)
% plot(h_r,FHRW,'b')
% grid on 
% xlabel('Ridge thickness, [m]')
% ylabel('Horizontal Ice Force, [N]')
% hold on
% plot(h_r,FHIn,'g')
% plot(h_r,FHCr,'k')
% plot(h_r,R11,'r')
% legend('Wang','Ralston, initial crack','Ralston, hinge crack','Maximum allowable force','Location','NorthWest')

% figure(4)
% plot(h_f,FHS2,'b')
% grid on 
% xlabel('Thickness of managed floes, [m]')
% ylabel('Horizontal Ice Force, [N]')
% hold on
% plot(h_f,FHS3,'k')
% plot(h_f,R11,'r')
% legend('Scenario 2','Scenario 3','Maximum allowable force','Location','North')

% figure(5)
% plot(h,FHS1,'k')
% grid on 
% xlabel('Pack ice thickness, [m]')
% ylabel('Horizontal Ice Force, [N]')
% hold on
% plot(h,R11,'r')
% legend('Scenario 1','Maximum allowable force','Location','NorthEast')
% xlim([0 4])

matlab2tikz( 'FirstYearRidge.tikz', 'height', '\figureheight', 'width', '\figurewidth' );

